@@ -12,7 +12,6 @@ our @EXPORT_OK = qw(
   CLEAR_DOWNLOADS
   CLEAR_MEDIA_DEVICES
   CLEAR_DOM_QUOTA
-  CLEAR_PREDICTOR_NETWORK_DATA
   CLEAR_DOM_PUSH_NOTIFICATIONS
   CLEAR_HISTORY
   CLEAR_AUTH_TOKENS
@@ -45,7 +44,7 @@ our @EXPORT_OK = qw(
 
 our %EXPORT_TAGS = ( 'all' => \@EXPORT_OK, );
 
-our $VERSION = '1.68';
+our $VERSION = '1.69';
 
 sub CLEAR_COOKIES                          { return 1 }
 sub CLEAR_NETWORK_CACHE                    { return 2 }
@@ -54,7 +53,6 @@ sub CLEAR_JS_CACHE                         { return 8 }
 sub CLEAR_DOWNLOADS                        { return 16 }
 sub CLEAR_MEDIA_DEVICES                    { return 64 }
 sub CLEAR_DOM_QUOTA                        { return 128 }
-sub CLEAR_PREDICTOR_NETWORK_DATA           { return 256 }
 sub CLEAR_DOM_PUSH_NOTIFICATIONS           { return 512 }
 sub CLEAR_HISTORY                          { return 1024 }
 sub CLEAR_MESSAGING_LAYER_SECURITY_STATE   { return 2048 }
@@ -105,10 +103,10 @@ sub CLEAR_FORGET_ABOUT_SITE {
     return CLEAR_HISTORY() | CLEAR_ALL_CACHES() | CLEAR_COOKIES() |
       CLEAR_EME() | CLEAR_DOWNLOADS() | CLEAR_PERMISSIONS() |
       CLEAR_DOM_STORAGES() | CLEAR_CONTENT_PREFERENCES() |
-      CLEAR_PREDICTOR_NETWORK_DATA() | CLEAR_DOM_PUSH_NOTIFICATIONS() |
-      CLEAR_CLIENT_AUTH_REMEMBER_SERVICE() | CLEAR_REPORTS() |
-      CLEAR_CERT_EXCEPTIONS() | CLEAR_CREDENTIAL_MANAGER_STATE() |
-      CLEAR_COOKIE_BANNER_EXCEPTION() | CLEAR_COOKIE_BANNER_EXECUTED_RECORD() |
+      CLEAR_DOM_PUSH_NOTIFICATIONS() | CLEAR_CLIENT_AUTH_REMEMBER_SERVICE() |
+      CLEAR_REPORTS() | CLEAR_CERT_EXCEPTIONS() |
+      CLEAR_CREDENTIAL_MANAGER_STATE() | CLEAR_COOKIE_BANNER_EXCEPTION() |
+      CLEAR_COOKIE_BANNER_EXECUTED_RECORD() |
       CLEAR_FINGERPRINTING_PROTECTION_STATE() |
       CLEAR_BOUNCE_TRACKING_PROTECTION_STATE() |
       CLEAR_MESSAGING_LAYER_SECURITY_STATE();
@@ -122,7 +120,7 @@ Firefox::Marionette::Cache - Constants to describe actions on the cache
 
 =head1 VERSION
 
-Version 1.68
+Version 1.69
 
 =head1 SYNOPSIS
 
@@ -173,10 +171,6 @@ returns the value of CLEAR_MEDIA_DEVICES, which is 1 << 6 = 64
 
 returns the value of CLEAR_DOM_QUOTA, which is 1 << 7 = 128 (LocalStorage, IndexedDB, ServiceWorkers, DOM Cache and so on.)
 
-=head2 CLEAR_PREDICTOR_NETWORK_DATA
-
-returns the value of CLEAR_PREDICTOR_NETWORK_DATA, which is 1 << 8 = 256 
-
 =head2 CLEAR_DOM_PUSH_NOTIFICATIONS
 
 returns the value of CLEAR_DOM_PUSH_NOTIFICATIONS, which is 1 << 9 = 512
@@ -287,7 +281,7 @@ returns the value of CLEAR_DOM_STORAGES, which is (L<CLEAR_DOM_QUOTA|/CLEAR_DOM_
 
 =head2 CLEAR_FORGET_ABOUT_SITE
 
-returns the value of CLEAR_FORGET_ABOUT_SITE, which is (L<CLEAR_HISTORY|/CLEAR_HISTORY> | L<CLEAR_ALL_CACHES|/CLEAR_ALL_CACHES> | L<CLEAR_COOKIES|/CLEAR_COOKIES> | L<CLEAR_EME|/CLEAR_EME> | L<CLEAR_DOWNLOADS|/CLEAR_DOWNLOADS> | L<CLEAR_PERMISSIONS|/CLEAR_PERMISSIONS> | L<CLEAR_DOM_STORAGES|/CLEAR_DOM_STORAGES> | L<CLEAR_CONTENT_PREFERENCES|/CLEAR_CONTENT_PREFERENCES> | L<CLEAR_PREDICTOR_NETWORK_DATA|/CLEAR_PREDICTOR_NETWORK_DATA> | L<CLEAR_DOM_PUSH_NOTIFICATIONS|/CLEAR_DOM_PUSH_NOTIFICATIONS> | L<CLEAR_CLIENT_AUTH_REMEMBER_SERVICE|/CLEAR_CLIENT_AUTH_REMEMBER_SERVICE> | L<CLEAR_REPORTS|/CLEAR_REPORTS> | L<CLEAR_CERT_EXCEPTIONS|/CLEAR_CERT_EXCEPTIONS> | L<CLEAR_CREDENTIAL_MANAGER_STATE|/CLEAR_CREDENTIAL_MANAGER_STATE> | L<CLEAR_COOKIE_BANNER_EXECUTED_RECORD|/CLEAR_COOKIE_BANNER_EXECUTED_RECORD> | L<CLEAR_FINGERPRINTING_PROTECTION_STATE|/CLEAR_FINGERPRINTING_PROTECTION_STATE> | L<CLEAR_MESSAGING_LAYER_SECURITY_STATE|/CLEAR_MESSAGING_LAYER_SECURITY_STATE>)
+returns the value of CLEAR_FORGET_ABOUT_SITE, which is (L<CLEAR_HISTORY|/CLEAR_HISTORY> | L<CLEAR_ALL_CACHES|/CLEAR_ALL_CACHES> | L<CLEAR_COOKIES|/CLEAR_COOKIES> | L<CLEAR_EME|/CLEAR_EME> | L<CLEAR_DOWNLOADS|/CLEAR_DOWNLOADS> | L<CLEAR_PERMISSIONS|/CLEAR_PERMISSIONS> | L<CLEAR_DOM_STORAGES|/CLEAR_DOM_STORAGES> | L<CLEAR_CONTENT_PREFERENCES|/CLEAR_CONTENT_PREFERENCES> | L<CLEAR_DOM_PUSH_NOTIFICATIONS|/CLEAR_DOM_PUSH_NOTIFICATIONS> | L<CLEAR_CLIENT_AUTH_REMEMBER_SERVICE|/CLEAR_CLIENT_AUTH_REMEMBER_SERVICE> | L<CLEAR_REPORTS|/CLEAR_REPORTS> | L<CLEAR_CERT_EXCEPTIONS|/CLEAR_CERT_EXCEPTIONS> | L<CLEAR_CREDENTIAL_MANAGER_STATE|/CLEAR_CREDENTIAL_MANAGER_STATE> | L<CLEAR_COOKIE_BANNER_EXECUTED_RECORD|/CLEAR_COOKIE_BANNER_EXECUTED_RECORD> | L<CLEAR_FINGERPRINTING_PROTECTION_STATE|/CLEAR_FINGERPRINTING_PROTECTION_STATE> | L<CLEAR_MESSAGING_LAYER_SECURITY_STATE|/CLEAR_MESSAGING_LAYER_SECURITY_STATE>)
 
 =head2 CLEAR_COOKIES_AND_SITE_DATA
 
